@@ -13,10 +13,10 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef JUK_COVERICONVIEW_H
-#define JUK_COVERICONVIEW_H
+#ifndef COVERICONVIEW_H
+#define COVERICONVIEW_H
 
-#include <kiconview.h>
+#include <k3iconview.h>
 
 #include "covermanager.h"
 
@@ -24,39 +24,40 @@
 // don't like the idea of naming it "CoverIVI" or something, so just namespace
 // it out.  I would merge them except for webimagefetcher's dependence on KIO
 // and such.
+
 namespace CoverUtility
 {
-    class CoverIconViewItem : public KIconViewItem
+    class CoverIconViewItem : public K3IconViewItem
     {
     public:
-	CoverIconViewItem(coverKey id, QIconView *parent);
+        CoverIconViewItem(coverKey id, Q3IconView *parent);
 
-	coverKey id() const { return m_id; }
+        coverKey id() const { return m_id; }
 
     private:
-	coverKey m_id;
+        coverKey m_id;
     };
 }
 
 using CoverUtility::CoverIconViewItem;
 
 /**
- * This class subclasses KIconView in order to provide cover drag-and-drop
+ * This class subclasses K3IconView in order to provide cover drag-and-drop
  * support.
  *
  * @author Michael Pyne <michael.pyne@kdemail.net>
  */
-class CoverIconView : public KIconView
+class CoverIconView : public K3IconView
 {
 public:
-    CoverIconView(QWidget *parent, const char *name);
+    explicit CoverIconView(QWidget *parent, const char *name = 0);
 
     CoverIconViewItem *currentItem() const;
 
 protected:
-    virtual QDragObject *dragObject();
+    virtual Q3DragObject *dragObject();
 };
 
-#endif /* JUK_COVERICONVIEW_H */
+#endif /* COVERICONVIEW_H */
 
-// vim: set et ts=4 sw=4:
+// vim: set et sw=4 tw=0 sta:
