@@ -13,24 +13,39 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <kiconloader.h>
-#include <kurldrag.h>
-#include <kmessagebox.h>
-#include <kpopupmenu.h>
-#include <kaction.h>
-#include <kdebug.h>
-
-#include <qheader.h>
-#include <qpainter.h>
-#include <qtimer.h>
-
 #include "playlistbox.h"
+
+#include <kicon.h>
+#include <kiconloader.h>
+#include <k3urldrag.h>
+#include <kmessagebox.h>
+#include <kmenu.h>
+#include <kaction.h>
+#include <kactioncollection.h>
+#include <kdebug.h>
+#include <ktoggleaction.h>
+#include <kselectaction.h>
+#include <kconfiggroup.h>
+
+#include <Q3Header>
+#include <QPainter>
+#include <QTimer>
+#include <QDragLeaveEvent>
+#include <QList>
+#include <QDragMoveEvent>
+#include <QKeyEvent>
+#include <QDropEvent>
+#include <QMouseEvent>
+#include <QFileInfo>
+#include <QApplication>
+#include <QClipboard>
+
 #include "playlist.h"
 #include "collectionlist.h"
 #include "covermanager.h"
 #include "dynamicplaylist.h"
-#include "historyplaylist.h"
 #include "upcomingplaylist.h"
+#include "historyplaylist.h"
 #include "viewmode.h"
 #include "searchplaylist.h"
 #include "treeviewitemplaylist.h"
@@ -46,9 +61,8 @@ using namespace ActionCollection;
 // PlaylistBox public methods
 ////////////////////////////////////////////////////////////////////////////////
 
-PlaylistBox::PlaylistBox(QWidget *parent, QWidgetStack *playlistStack,
-			 const char *name) :
-    KListView(parent, name),
+PlaylistBox::PlaylistBox(QWidget *parent, Q3WidgetStack *playlistStack) :
+    K3ListView(parent),
     PlaylistCollection(playlistStack),
     m_viewModeIndex(0),
     m_hasSelection(false),
@@ -70,28 +84,29 @@ PlaylistBox::PlaylistBox(QWidget *parent, QWidgetStack *playlistStack,
     setAcceptDrops(true);
     setSelectionModeExt(Extended);
 
-    m_contextMenu = new KPopupMenu(this);
+    m_contextMenu = new KMenu(this);
 
     K3bPlaylistExporter *exporter = new K3bPlaylistExporter(this);
     m_k3bAction = exporter->action();
 
-    action("file_new")->plug(m_contextMenu);
-    action("renamePlaylist")->plug(m_contextMenu);
-    action("editSearch")->plug(m_contextMenu);
-    action("duplicatePlaylist")->plug(m_contextMenu);
-    action("reloadPlaylist")->plug(m_contextMenu);
-    action("deleteItemPlaylist")->plug(m_contextMenu);
-    action("file_save")->plug(m_contextMenu);
-    action("file_save_as")->plug(m_contextMenu);
+    m_contextMenu->addAction( action("file_new") );
+    m_contextMenu->addAction( action("renamePlaylist") );
+    m_contextMenu->addAction( action("editSearch") );
+    m_contextMenu->addAction( action("duplicatePlaylist") );
+    m_contextMenu->addAction( action("reloadPlaylist") );
+    m_contextMenu->addAction( action("deleteItemPlaylist") );
+    m_contextMenu->addAction( action("file_save") );
+    m_contextMenu->addAction( action("file_save_as") );
     if(m_k3bAction)
-	m_k3bAction->plug(m_contextMenu);
+        m_contextMenu->addAction( m_k3bAction );
 
-    m_contextMenu->insertSeparator();
+    m_contextMenu->addSeparator();
 
     // add the view modes stuff
 
     KSelectAction *viewModeAction =
-	new KSelectAction(i18n("View Modes"), "view_choose", KShortcut(), actions(), "viewModeMenu");
+        new KSelectAction( KIcon("view-choose"), i18n("View Modes"), ActionCollection::actions());
+    ActionCollection::actions()->addAction("viewModeMenu", viewModeAction);
 
     m_viewModes.append(new ViewMode(this));
     m_viewModes.append(new CompactViewMode(this));
@@ -100,15 +115,20 @@ PlaylistBox::PlaylistBox(QWidget *parent, QWidgetStack *playlistStack,
 
     QStringList modeNames;
 
-    for(QValueListIterator<ViewMode *> it = m_viewModes.begin(); it != m_viewModes.end(); ++it)
-	modeNames.append((*it)->name());
+    for(QList<ViewMode *>::Iterator it = m_viewModes.begin(); it != m_viewModes.end(); ++it)
+        modeNames.append((*it)->name());
 
     viewModeAction->setItems(modeNames);
 
-    QPopupMenu *p = viewModeAction->popupMenu();
-    p->changeItem(0, SmallIconSet("view_detailed"), modeNames[0]);
-    p->changeItem(1, SmallIconSet("view_text"), modeNames[1]);
-    p->changeItem(2, SmallIconSet("view_tree"), modeNames[2]);
+#ifdef __GNUC__
+#warning This needs to be ported to proper QActions
+#endif
+#if 0
+    QMenu *p = viewModeAction->menu();
+    p->changeItem(0, SmallIconSet("view-list-details"), modeNames[0]);
+    p->changeItem(1, SmallIconSet("view-list-text"), modeNames[1]);
+    p->changeItem(2, SmallIconSet("view-list-tree"), modeNames[2]);
+#endif
 
     CollectionList::initialize(this);
     Cache::loadPlaylists(this);
@@ -119,17 +139,17 @@ PlaylistBox::PlaylistBox(QWidget *parent, QWidgetStack *playlistStack,
     TrackSequenceManager::instance()->setCurrentPlaylist(CollectionList::instance());
     raise(CollectionList::instance());
 
-    viewModeAction->plug(m_contextMenu);
+    m_contextMenu->addAction( viewModeAction );
     connect(viewModeAction, SIGNAL(activated(int)), this, SLOT(slotSetViewMode(int)));
 
     connect(this, SIGNAL(selectionChanged()),
-	    this, SLOT(slotPlaylistChanged()));
+            this, SLOT(slotPlaylistChanged()));
 
-    connect(this, SIGNAL(doubleClicked(QListViewItem *)),
-	    this, SLOT(slotDoubleClicked()));
+    connect(this, SIGNAL(doubleClicked(Q3ListViewItem *)),
+            this, SLOT(slotDoubleClicked()));
 
-    connect(this, SIGNAL(contextMenuRequested(QListViewItem *, const QPoint &, int)),
-	    this, SLOT(slotShowContextMenu(QListViewItem *, const QPoint &, int)));
+    connect(this, SIGNAL(contextMenuRequested(Q3ListViewItem *, const QPoint &, int)),
+            this, SLOT(slotShowContextMenu(Q3ListViewItem *, const QPoint &, int)));
 
     TagTransactionManager *tagManager = TagTransactionManager::instance();
     connect(tagManager, SIGNAL(signalAboutToModifyTags()), SLOT(slotFreezePlaylists()));
@@ -156,10 +176,10 @@ PlaylistBox::~PlaylistBox()
 {
     PlaylistList l;
     CollectionList *collection = CollectionList::instance();
-    for(QListViewItem *i = firstChild(); i; i = i->nextSibling()) {
-	Item *item = static_cast<Item *>(i);
-	if(item->playlist() && item->playlist() != collection)
-	    l.append(item->playlist());
+    for(Q3ListViewItem *i = firstChild(); i; i = i->nextSibling()) {
+        Item *item = static_cast<Item *>(i);
+        if(item->playlist() && item->playlist() != collection)
+            l.append(item->playlist());
     }
 
     Cache::savePlaylists(l);
@@ -169,20 +189,20 @@ PlaylistBox::~PlaylistBox()
 void PlaylistBox::raise(Playlist *playlist)
 {
     if(!playlist)
-	return;
+        return;
 
-    Item *i = m_playlistDict.find(playlist);
+    Item *i = m_playlistDict.value(playlist, 0);
 
     if(i) {
-	clearSelection();
-	setSelected(i, true);
+        clearSelection();
+        setSelected(i, true);
 
-	setSingleItem(i);
-	ensureItemVisible(currentItem());
+        setSingleItem(i);
+        ensureItemVisible(currentItem());
     }
     else
-	PlaylistCollection::raise(playlist);
-    
+        PlaylistCollection::raise(playlist);
+
     slotPlaylistChanged();
 }
 
@@ -190,12 +210,12 @@ void PlaylistBox::duplicate()
 {
     Item *item = static_cast<Item *>(currentItem());
     if(!item || !item->playlist())
-	return;
+        return;
 
-    QString name = playlistNameDialog(i18n("Duplicate"), item->text(0));
+    QString name = playlistNameDialog(i18nc("verb, copy the playlist", "Duplicate"), item->text(0));
 
     if(name.isNull())
-	return;
+        return;
 
     Playlist *p = new Playlist(this, name);
     p->createItems(item->playlist()->items());
@@ -208,7 +228,7 @@ void PlaylistBox::duplicate()
 void PlaylistBox::paste()
 {
     Item *i = static_cast<Item *>(currentItem());
-    decode(kapp->clipboard()->data(), i);
+    decode(QApplication::clipboard()->mimeData(), i);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -233,19 +253,22 @@ void PlaylistBox::setupPlaylist(Playlist *playlist, const QString &iconName)
 void PlaylistBox::setupPlaylist(Playlist *playlist, const QString &iconName, Item *parentItem)
 {
     connect(playlist, SIGNAL(signalPlaylistItemsDropped(Playlist *)),
-	    SLOT(slotPlaylistItemsDropped(Playlist *)));
+            SLOT(slotPlaylistItemsDropped(Playlist *)));
 
     PlaylistCollection::setupPlaylist(playlist, iconName);
 
     if(parentItem)
-	new Item(parentItem, iconName, playlist->name(), playlist);
+        new Item(parentItem, iconName, playlist->name(), playlist);
     else
-	new Item(this, iconName, playlist->name(), playlist);
+        new Item(this, iconName, playlist->name(), playlist);
 }
 
 void PlaylistBox::removePlaylist(Playlist *playlist)
 {
-    removeNameFromDict(m_playlistDict[playlist]->text(0));
+    // Could be false if setup() wasn't run yet.
+    if(m_playlistDict.contains(playlist))
+        removeNameFromDict(m_playlistDict[playlist]->text(0));
+
     removeFileFromDict(playlist->fileName());
     m_playlistDict.remove(playlist);
 }
@@ -257,7 +280,7 @@ void PlaylistBox::removePlaylist(Playlist *playlist)
 void PlaylistBox::readConfig()
 {
     KConfigGroup config(KGlobal::config(), "PlaylistBox");
-    m_viewModeIndex = config.readNumEntry("ViewMode", 0);
+    m_viewModeIndex = config.readEntry("ViewMode", 0);
 }
 
 void PlaylistBox::saveConfig()
@@ -269,107 +292,110 @@ void PlaylistBox::saveConfig()
 
 void PlaylistBox::remove()
 {
-    ItemList items = selectedItems();
+    ItemList items = selectedBoxItems();
 
     if(items.isEmpty())
-	return;
+        return;
 
     QStringList files;
     QStringList names;
 
-    for(ItemList::ConstIterator it = items.begin(); it != items.end(); ++it) {
-	if(*it && (*it)->playlist() &&
-	   !(*it)->playlist()->fileName().isEmpty() &&
-	   QFileInfo((*it)->playlist()->fileName()).exists())
-	{
-	    files.append((*it)->playlist()->fileName());
-	}
-	names.append((*it)->playlist()->name());
+    foreach(Item *item, items) {
+        if(item && item->playlist()) 
+        {
+           if (!item->playlist()->fileName().isEmpty() &&
+               QFileInfo(item->playlist()->fileName()).exists())
+           {
+            files.append(item->playlist()->fileName());
+           }
+
+           names.append(item->playlist()->name());
+        }
     }
 
     if(!files.isEmpty()) {
-	int remove = KMessageBox::warningYesNoCancelList(
-	    this, i18n("Do you want to delete these files from the disk as well?"), files, QString::null, KStdGuiItem::del(), i18n("Keep"));
+        int remove = KMessageBox::warningYesNoCancelList(
+            this, i18n("Do you want to delete these files from the disk as well?"), files, QString(), KStandardGuiItem::del(), KGuiItem(i18n("Keep")));
 
-	if(remove == KMessageBox::Yes) {
-	    QStringList couldNotDelete;
-	    for(QStringList::ConstIterator it = files.begin(); it != files.end(); ++it) {
-		if(!QFile::remove(*it))
-		    couldNotDelete.append(*it);
-	    }
+        if(remove == KMessageBox::Yes) {
+            QStringList couldNotDelete;
+            for(QStringList::ConstIterator it = files.begin(); it != files.end(); ++it) {
+                if(!QFile::remove(*it))
+                    couldNotDelete.append(*it);
+            }
 
-	    if(!couldNotDelete.isEmpty())
-		KMessageBox::errorList(this, i18n("Could not delete these files."), couldNotDelete);
-	}
-	else if(remove == KMessageBox::Cancel)
-	    return;
+            if(!couldNotDelete.isEmpty())
+                KMessageBox::errorList(this, i18n("Could not delete these files."), couldNotDelete);
+        }
+        else if(remove == KMessageBox::Cancel)
+            return;
     }
     else if(items.count() > 1 || items.front()->playlist() != upcomingPlaylist()) {
-	if(KMessageBox::warningContinueCancelList(this,
-						  i18n("Are you sure you want to remove these "
-						       "playlists from your collection?"),
-						  names,
-						  i18n("Remove Items?"),
-						  KGuiItem(i18n("&Remove"), "edittrash")) == KMessageBox::Cancel)
-	{
-	    return;
-	}
+        if(KMessageBox::warningContinueCancelList(this,
+                                                  i18n("Are you sure you want to remove these "
+                                                       "playlists from your collection?"),
+                                                  names,
+                                                  i18n("Remove Items?"),
+                                                  KGuiItem(i18n("&Remove"), "user-trash")) == KMessageBox::Cancel)
+        {
+            return;
+        }
     }
 
     PlaylistList removeQueue;
 
     for(ItemList::ConstIterator it = items.begin(); it != items.end(); ++it) {
-	if(*it != Item::collectionItem() &&
-	   (*it)->playlist() &&
-	   (!(*it)->playlist()->readOnly()))
-	{
-	    removeQueue.append((*it)->playlist());
-	}
+        if(*it != Item::collectionItem() &&
+           (*it)->playlist() &&
+           (!(*it)->playlist()->readOnly()))
+        {
+            removeQueue.append((*it)->playlist());
+        }
     }
 
     if(items.back()->nextSibling() && static_cast<Item *>(items.back()->nextSibling())->playlist())
-	setSingleItem(items.back()->nextSibling());
+        setSingleItem(items.back()->nextSibling());
     else {
-	Item *i = static_cast<Item *>(items.front()->itemAbove());
-	while(i && !i->playlist())
-	    i = static_cast<Item *>(i->itemAbove());
+        Item *i = static_cast<Item *>(items.front()->itemAbove());
+        while(i && !i->playlist())
+            i = static_cast<Item *>(i->itemAbove());
 
-	if(!i)
-	    i = Item::collectionItem();
+        if(!i)
+            i = Item::collectionItem();
 
-	setSingleItem(i);
+        setSingleItem(i);
     }
 
     for(PlaylistList::ConstIterator it = removeQueue.begin(); it != removeQueue.end(); ++it) {
-	if(*it != upcomingPlaylist())
-	    delete *it;
-	else {
-	    action<KToggleAction>("showUpcoming")->setChecked(false);
-	    setUpcomingPlaylistEnabled(false);
-	}
+        if(*it != upcomingPlaylist())
+            delete *it;
+        else {
+            action<KToggleAction>("showUpcoming")->setChecked(false);
+            setUpcomingPlaylistEnabled(false);
+        }
     }
 }
 
 void PlaylistBox::setDynamicListsFrozen(bool frozen)
 {
-    for(QValueList<ViewMode *>::Iterator it = m_viewModes.begin();
-	it != m_viewModes.end();
-	++it)
+    for(QList<ViewMode *>::Iterator it = m_viewModes.begin();
+        it != m_viewModes.end();
+        ++it)
     {
-	(*it)->setDynamicListsFrozen(frozen);
+        (*it)->setDynamicListsFrozen(frozen);
     }
 }
 
 void PlaylistBox::slotSavePlaylists()
 {
-    kdDebug(65432) << "Auto-saving playlists and covers.\n";
+    kDebug(65432) << "Auto-saving playlists and covers.\n";
 
     PlaylistList l;
     CollectionList *collection = CollectionList::instance();
-    for(QListViewItem *i = firstChild(); i; i = i->nextSibling()) {
-	Item *item = static_cast<Item *>(i);
-	if(item->playlist() && item->playlist() != collection)
-	    l.append(item->playlist());
+    for(Q3ListViewItem *i = firstChild(); i; i = i->nextSibling()) {
+        Item *item = static_cast<Item *>(i);
+        if(item->playlist() && item->playlist() != collection)
+            l.append(item->playlist());
     }
 
     Cache::savePlaylists(l);
@@ -381,8 +407,8 @@ void PlaylistBox::slotSavePlaylists()
 void PlaylistBox::slotShowDropTarget()
 {
     if(!m_dropItem) {
-	kdError(65432) << "Trying to show the playlist of a null item!\n";
-	return;
+        kError(65432) << "Trying to show the playlist of a null item!\n";
+        return;
     }
 
     raise(m_dropItem->playlist());
@@ -390,48 +416,48 @@ void PlaylistBox::slotShowDropTarget()
 
 void PlaylistBox::slotAddItem(const QString &tag, unsigned column)
 {
-    for(QValueListIterator<ViewMode *> it = m_viewModes.begin(); it != m_viewModes.end(); ++it)
-	(*it)->addItems(tag, column);
+    for(QList<ViewMode *>::Iterator it = m_viewModes.begin(); it != m_viewModes.end(); ++it)
+        (*it)->addItems(QStringList(tag), column);
 }
 
 void PlaylistBox::slotRemoveItem(const QString &tag, unsigned column)
 {
-    for(QValueListIterator<ViewMode *> it = m_viewModes.begin(); it != m_viewModes.end(); ++it)
-	(*it)->removeItem(tag, column);
+    for(QList<ViewMode *>::Iterator it = m_viewModes.begin(); it != m_viewModes.end(); ++it)
+        (*it)->removeItem(tag, column);
 }
 
-void PlaylistBox::decode(QMimeSource *s, Item *item)
+void PlaylistBox::decode(const QMimeData *s, Item *item)
 {
     if(!s || (item && item->playlist() && item->playlist()->readOnly()))
-	return;
+        return;
 
-    KURL::List urls;
+    KUrl::List urls = KUrl::List::fromMimeData(s);
 
-    if(KURLDrag::decode(s, urls) && !urls.isEmpty()) {
-	QStringList files;
-	for(KURL::List::Iterator it = urls.begin(); it != urls.end(); ++it)
-	    files.append((*it).path());
+    if(!urls.isEmpty()) {
+        QStringList files;
+        for(KUrl::List::Iterator it = urls.begin(); it != urls.end(); ++it)
+            files.append((*it).path());
 
-	if(item) {
-	    TreeViewItemPlaylist *playlistItem;
-	    playlistItem = dynamic_cast<TreeViewItemPlaylist *>(item->playlist());
-	    if(playlistItem) {
-		playlistItem->retag(files, currentPlaylist());
-		TagTransactionManager::instance()->commit();
-		currentPlaylist()->update();
-		return;
-	    }
-	}
+        if(item) {
+            TreeViewItemPlaylist *playlistItem;
+            playlistItem = dynamic_cast<TreeViewItemPlaylist *>(item->playlist());
+            if(playlistItem) {
+                playlistItem->retag(files, currentPlaylist());
+                TagTransactionManager::instance()->commit();
+                currentPlaylist()->update();
+                return;
+            }
+        }
 
-	if(item && item->playlist())
-	    item->playlist()->addFiles(files);
-	else {
-	    QString name = playlistNameDialog();
-	    if(!name.isNull()) {
-		Playlist *p = new Playlist(this, name);
-		p->addFiles(files);
-	    }
-	}
+        if(item && item->playlist())
+            item->playlist()->addFiles(files);
+        else {
+            QString name = playlistNameDialog();
+            if(!name.isNull()) {
+                Playlist *p = new Playlist(this, name);
+                p->addFiles(files);
+            }
+        }
     }
 }
 
@@ -440,12 +466,12 @@ void PlaylistBox::contentsDropEvent(QDropEvent *e)
     m_showTimer->stop();
 
     Item *i = static_cast<Item *>(itemAt(contentsToViewport(e->pos())));
-    decode(e, i);
+    decode(e->mimeData(), i);
 
     if(m_dropItem) {
-	Item *old = m_dropItem;
-	m_dropItem = 0;
-	old->repaint();
+        Item *old = m_dropItem;
+        m_dropItem = 0;
+        old->repaint();
     }
 }
 
@@ -457,118 +483,119 @@ void PlaylistBox::contentsDragMoveEvent(QDragMoveEvent *e)
     //
     // Otherwise, do not accept the event.
 
-    if(!KURLDrag::canDecode(e)) {
-	e->accept(false);
-	return;
+    if(!K3URLDrag::canDecode(e)) {
+        e->setAccepted(false);
+        return;
     }
 
     Item *target = static_cast<Item *>(itemAt(contentsToViewport(e->pos())));
 
     if(target) {
 
-	if(target->playlist() && target->playlist()->readOnly())
-	    return;
+        if(target->playlist() && target->playlist()->readOnly())
+            return;
 
-	// This is a semi-dirty hack to check if the items are coming from within
-	// JuK.  If they are not coming from a Playlist (or subclass) then the
-	// dynamic_cast will fail and we can safely assume that the item is
-	// coming from outside of JuK.
+        // This is a semi-dirty hack to check if the items are coming from within
+        // JuK.  If they are not coming from a Playlist (or subclass) then the
+        // dynamic_cast will fail and we can safely assume that the item is
+        // coming from outside of JuK.
 
-	if(dynamic_cast<Playlist *>(e->source())) {
-	    if(target->playlist() &&
-	       target->playlist() != CollectionList::instance() &&
-	       !target->isSelected())
-	    {
-		e->accept(true);
-	    }
-	    else
-		e->accept(false);
-	}
-	else // the dropped items are coming from outside of JuK
-	    e->accept(true);
+        if(dynamic_cast<Playlist *>(e->source())) {
+            if(target->playlist() &&
+               target->playlist() != CollectionList::instance() &&
+               !target->isSelected())
+            {
+                e->setAccepted(true);
+            }
+            else
+                e->setAccepted(false);
+        }
+        else // the dropped items are coming from outside of JuK
+            e->setAccepted(true);
 
-	if(m_dropItem != target) {
-	    Item *old = m_dropItem;
-	    m_showTimer->stop();
+        if(m_dropItem != target) {
+            Item *old = m_dropItem;
+            m_showTimer->stop();
 
-	    if(e->isAccepted()) {
-		m_dropItem = target;
-		target->repaint();
-		m_showTimer->start(1500, true);
-	    }
-	    else
-		m_dropItem = 0;
+            if(e->isAccepted()) {
+                m_dropItem = target;
+                target->repaint();
+                m_showTimer->setSingleShot(true);
+                m_showTimer->start(1500);
+            }
+            else
+                m_dropItem = 0;
 
-	    if(old)
-		old->repaint();
-	}
+            if(old)
+                old->repaint();
+        }
     }
     else {
 
-	// We're dragging over the whitespace.  We'll use this case to make it
-	// possible to create new lists.
+        // We're dragging over the whitespace.  We'll use this case to make it
+        // possible to create new lists.
 
-	e->accept(true);
+        e->setAccepted(true);
     }
 }
 
 void PlaylistBox::contentsDragLeaveEvent(QDragLeaveEvent *e)
 {
     if(m_dropItem) {
-	Item *old = m_dropItem;
-	m_dropItem = 0;
-	old->repaint();
+        Item *old = m_dropItem;
+        m_dropItem = 0;
+        old->repaint();
     }
-    KListView::contentsDragLeaveEvent(e);
+    K3ListView::contentsDragLeaveEvent(e);
 }
 
 void PlaylistBox::contentsMousePressEvent(QMouseEvent *e)
 {
-    if(e->button() == LeftButton)
-	m_doingMultiSelect = true;
-    KListView::contentsMousePressEvent(e);
+    if(e->button() == Qt::LeftButton)
+        m_doingMultiSelect = true;
+    K3ListView::contentsMousePressEvent(e);
 }
 
 void PlaylistBox::contentsMouseReleaseEvent(QMouseEvent *e)
 {
-    if(e->button() == LeftButton) {
-	m_doingMultiSelect = false;
-	slotPlaylistChanged();
+    if(e->button() == Qt::LeftButton) {
+        m_doingMultiSelect = false;
+        slotPlaylistChanged();
     }
-    KListView::contentsMouseReleaseEvent(e);
+    K3ListView::contentsMouseReleaseEvent(e);
 }
 
 void PlaylistBox::keyPressEvent(QKeyEvent *e)
 {
-    if((e->key() == Key_Up || e->key() == Key_Down) && e->state() == ShiftButton)
-	m_doingMultiSelect = true;
-    KListView::keyPressEvent(e);
+    if((e->key() == Qt::Key_Up || e->key() == Qt::Key_Down) && e->modifiers() == Qt::ShiftButton)
+        m_doingMultiSelect = true;
+    K3ListView::keyPressEvent(e);
 }
 
 void PlaylistBox::keyReleaseEvent(QKeyEvent *e)
 {
-    if(m_doingMultiSelect && e->key() == Key_Shift) {
-	m_doingMultiSelect = false;
-	slotPlaylistChanged();
+    if(m_doingMultiSelect && e->key() == Qt::Key_Shift) {
+        m_doingMultiSelect = false;
+        slotPlaylistChanged();
     }
-    KListView::keyReleaseEvent(e);
+    K3ListView::keyReleaseEvent(e);
 }
 
-PlaylistBox::ItemList PlaylistBox::selectedItems() const
+PlaylistBox::ItemList PlaylistBox::selectedBoxItems() const
 {
     ItemList l;
 
-    for(QListViewItemIterator it(const_cast<PlaylistBox *>(this),
-				 QListViewItemIterator::Selected); it.current(); ++it)
-	l.append(static_cast<Item *>(*it));
+    for(Q3ListViewItemIterator it(const_cast<PlaylistBox *>(this),
+                                 Q3ListViewItemIterator::Selected); it.current(); ++it)
+        l.append(static_cast<Item *>(*it));
 
     return l;
 }
 
-void PlaylistBox::setSingleItem(QListViewItem *item)
+void PlaylistBox::setSingleItem(Q3ListViewItem *item)
 {
     setSelectionModeExt(Single);
-    KListView::setCurrentItem(item);
+    K3ListView::setCurrentItem(item);
     setSelectionModeExt(Extended);
 }
 
@@ -581,9 +608,9 @@ void PlaylistBox::slotPlaylistChanged()
     // Don't update while the mouse is pressed down.
 
     if(m_doingMultiSelect)
-	return;
+        return;
 
-    ItemList items = selectedItems();
+    ItemList items = selectedBoxItems();
     m_hasSelection = !items.isEmpty();
 
     bool allowReload = false;
@@ -591,20 +618,20 @@ void PlaylistBox::slotPlaylistChanged()
     PlaylistList playlists;
     for(ItemList::ConstIterator it = items.begin(); it != items.end(); ++it) {
 
-	Playlist *p = (*it)->playlist();
-	if(p) {
-	    if(p->canReload())
-		allowReload = true;
-	    playlists.append(p);
-	}
+        Playlist *p = (*it)->playlist();
+        if(p) {
+            if(p->canReload())
+                allowReload = true;
+            playlists.append(p);
+        }
     }
 
     bool singlePlaylist = playlists.count() == 1;
 
     if(playlists.isEmpty() ||
        (singlePlaylist &&
-	(playlists.front() == CollectionList::instance() ||
-	 playlists.front()->readOnly())))
+        (playlists.front() == CollectionList::instance() ||
+         playlists.front()->readOnly())))
     {
         action("file_save")->setEnabled(false);
         action("file_save_as")->setEnabled(false);
@@ -621,30 +648,30 @@ void PlaylistBox::slotPlaylistChanged()
     action("duplicatePlaylist")->setEnabled(!playlists.isEmpty());
 
     if(m_k3bAction)
-	m_k3bAction->setEnabled(!playlists.isEmpty());
+        m_k3bAction->setEnabled(!playlists.isEmpty());
 
     action("editSearch")->setEnabled(singlePlaylist &&
-				     playlists.front()->searchIsEditable());
+                                     playlists.front()->searchIsEditable());
 
     if(singlePlaylist) {
-	PlaylistCollection::raise(playlists.front());
+        PlaylistCollection::raise(playlists.front());
 
-	if(playlists.front() == upcomingPlaylist())
-	    action("deleteItemPlaylist")->setText(i18n("Hid&e"));
-	else
-	    action("deleteItemPlaylist")->setText(i18n("R&emove"));
+        if(playlists.front() == upcomingPlaylist())
+            action("deleteItemPlaylist")->setText(i18n("Hid&e"));
+        else
+            action("deleteItemPlaylist")->setText(i18n("R&emove"));
     }
     else if(!playlists.isEmpty())
-	createDynamicPlaylist(playlists);
+        createDynamicPlaylist(playlists);
 }
 
 void PlaylistBox::slotDoubleClicked()
 {
-    action("stop")->activate();
-    action("play")->activate();
+    action("stop")->trigger();
+    action("play")->trigger();
 }
 
-void PlaylistBox::slotShowContextMenu(QListViewItem *, const QPoint &point, int)
+void PlaylistBox::slotShowContextMenu(Q3ListViewItem *, const QPoint &point, int)
 {
     m_contextMenu->popup(point);
 }
@@ -657,7 +684,7 @@ void PlaylistBox::slotPlaylistItemsDropped(Playlist *p)
 void PlaylistBox::slotSetViewMode(int index)
 {
     if(index == m_viewModeIndex)
-	return;
+        return;
 
     viewMode()->setShown(false);
     m_viewModeIndex = index;
@@ -673,7 +700,7 @@ void PlaylistBox::setupItem(Item *item)
 void PlaylistBox::setupUpcomingPlaylist()
 {
     KConfigGroup config(KGlobal::config(), "Playlists");
-    bool enable = config.readBoolEntry("showUpcoming", false);
+    bool enable = config.readEntry("showUpcoming", false);
 
     setUpcomingPlaylistEnabled(enable);
     action<KToggleAction>("showUpcoming")->setChecked(enable);
@@ -686,14 +713,14 @@ void PlaylistBox::setupUpcomingPlaylist()
 PlaylistBox::Item *PlaylistBox::Item::m_collectionItem = 0;
 
 PlaylistBox::Item::Item(PlaylistBox *listBox, const QString &icon, const QString &text, Playlist *l)
-    : QObject(listBox), KListViewItem(listBox, 0, text),
+    : QObject(listBox), K3ListViewItem(listBox, 0, text),
       m_playlist(l), m_text(text), m_iconName(icon), m_sortedFirst(false)
 {
     init();
 }
 
 PlaylistBox::Item::Item(Item *parent, const QString &icon, const QString &text, Playlist *l)
-    : QObject(parent->listView()), KListViewItem(parent, text),
+    : QObject(parent->listView()), K3ListViewItem(parent, text),
     m_playlist(l), m_text(text), m_iconName(icon), m_sortedFirst(false)
 {
     init();
@@ -704,22 +731,22 @@ PlaylistBox::Item::~Item()
 
 }
 
-int PlaylistBox::Item::compare(QListViewItem *i, int col, bool) const
+int PlaylistBox::Item::compare(Q3ListViewItem *i, int col, bool) const
 {
     Item *otherItem = static_cast<Item *>(i);
     PlaylistBox *playlistBox = static_cast<PlaylistBox *>(listView());
 
     if(m_playlist == playlistBox->upcomingPlaylist() && otherItem->m_playlist != CollectionList::instance())
-	return -1;
+        return -1;
     if(otherItem->m_playlist == playlistBox->upcomingPlaylist() && m_playlist != CollectionList::instance())
-	return 1;
+        return 1;
 
     if(m_sortedFirst && !otherItem->m_sortedFirst)
-	return -1;
+        return -1;
     else if(otherItem->m_sortedFirst && !m_sortedFirst)
-	return 1;
+        return 1;
 
-    return text(col).lower().localeAwareCompare(i->text(col).lower());
+    return text(col).toLower().localeAwareCompare(i->text(col).toLower());
 }
 
 void PlaylistBox::Item::paintCell(QPainter *painter, const QColorGroup &colorGroup, int column, int width, int align)
@@ -731,7 +758,7 @@ void PlaylistBox::Item::paintCell(QPainter *painter, const QColorGroup &colorGro
 void PlaylistBox::Item::setText(int column, const QString &text)
 {
     m_text = text;
-    KListViewItem::setText(column, text);
+    K3ListViewItem::setText(column, text);
 }
 
 void PlaylistBox::Item::setup()
@@ -746,12 +773,12 @@ void PlaylistBox::Item::setup()
 void PlaylistBox::Item::slotSetName(const QString &name)
 {
     if(listView()) {
-	setText(0, name);
-	setSelected(true);
+        setText(0, name);
+        setSelected(true);
 
-	listView()->sort();
-	listView()->ensureItemVisible(listView()->currentItem());
-	listView()->viewMode()->queueRefresh();
+        listView()->sort();
+        listView()->ensureItemVisible(listView()->currentItem());
+        listView()->viewMode()->queueRefresh();
     }
 }
 
@@ -770,21 +797,23 @@ void PlaylistBox::Item::init()
     list->addNameToDict(m_text);
 
     if(m_playlist) {
-	connect(m_playlist, SIGNAL(signalNameChanged(const QString &)),
-		this, SLOT(slotSetName(const QString &)));
-	connect(m_playlist, SIGNAL(destroyed()), this, SLOT(deleteLater()));
-	connect(m_playlist, SIGNAL(signalEnableDirWatch(bool)),
-	        list->object(), SLOT(slotEnableDirWatch(bool)));
+        connect(m_playlist, SIGNAL(signalNameChanged(const QString &)),
+                this, SLOT(slotSetName(const QString &)));
+        connect(m_playlist, SIGNAL(destroyed()), this, SLOT(deleteLater()));
+        connect(m_playlist, SIGNAL(signalEnableDirWatch(bool)),
+                list->object(), SLOT(slotEnableDirWatch(bool)));
     }
 
     if(m_playlist == CollectionList::instance()) {
-	m_sortedFirst = true;
-	m_collectionItem = this;
-	list->viewMode()->setupDynamicPlaylists();
+        m_sortedFirst = true;
+        m_collectionItem = this;
+        list->viewMode()->setupDynamicPlaylists();
     }
 
     if(m_playlist == list->historyPlaylist() || m_playlist == list->upcomingPlaylist())
-	m_sortedFirst = true;
+        m_sortedFirst = true;
 }
 
 #include "playlistbox.moc"
+
+// vim: set et sw=4 tw=0 sta:
