@@ -13,31 +13,46 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
 
 #include <config.h>
+
+// Linux has <endian.h>, FreeBSD has <sys/endian.h> and Solaris has neither.
+#ifdef HAVE_ENDIAN_H
 #include <endian.h>
+#else
+#ifdef HAVE_SYS_ENDIAN_H
+#include <sys/endian.h>
+#else
+#ifdef HAVE_MACHINE_ENDIAN_H
+#include <machine/endian.h>
+#endif
+#endif
+#endif
+#if !defined(__BYTE_ORDER) && defined(_BYTE_ORDER)
+#define __BYTE_ORDER _BYTE_ORDER
+#define __LITTLE_ENDIAN _LITTLE_ENDIAN
+#endif
+
 #include "encoderlame.h"
-#include "encoderlameconfig.h"
 #include "audiocd_lame_encoder.h"
 
 #include <kdebug.h>
 #include <qgroupbox.h>
-#include <kprocess.h>
-#include <kdebug.h>
+#include <k3process.h>
 
-#include <kglobal.h>
+#include <kglobal.h>  
 #include <klocale.h>
-#include <kapplication.h>
+#include <qapplication.h>
 #include <qfileinfo.h>
-#include <ktempfile.h>
+#include <ktemporaryfile.h>
 #include <kstandarddirs.h>
 #include "collectingprocess.h"
 
 extern "C"
 {
-	KDE_EXPORT void create_audiocd_encoders(KIO::SlaveBase *slave, QPtrList<AudioCDEncoder> &encoders) {
+	KDE_EXPORT void create_audiocd_encoders(KIO::SlaveBase *slave, QList<AudioCDEncoder*> &encoders) {
 		encoders.append(new EncoderLame(slave));
 	}
 }
@@ -53,8 +68,8 @@ public:
 	QString lastErrorMessage;
 	QStringList genreList;
 	uint lastSize;
-	KProcess *currentEncodeProcess;
-	KTempFile *tempFile;
+	K3Process *currentEncodeProcess;
+	KTemporaryFile *tempFile;
 };
 
 EncoderLame::EncoderLame(KIO::SlaveBase *slave) : QObject(), AudioCDEncoder(slave) {
@@ -70,11 +85,11 @@ EncoderLame::~EncoderLame(){
 }
 
 QWidget* EncoderLame::getConfigureWidget(KConfigSkeleton** manager) const {
-	(*manager) = Settings::self();
-	KGlobal::locale()->insertCatalogue("audiocd_encoder_lame");
-	EncoderLameConfig *config = new EncoderLameConfig();
-	config->cbr_settings->hide();
-	return config;
+  (*manager) = Settings::self();
+  KGlobal::locale()->insertCatalog("audiocd_encoder_lame");
+  EncoderLameConfig *config = new EncoderLameConfig();
+  config->cbr_settings->hide();
+  return config;
 }
 
 bool EncoderLame::init(){
@@ -86,27 +101,23 @@ bool EncoderLame::init(){
 	// e.g. lame --tg 'Vocal Jazz'
     CollectingProcess proc;
 	proc << "lame" << "--genre-list";
-	proc.start(KProcess::Block, KProcess::Stdout);
+	proc.start(K3Process::Block, K3Process::Stdout);
 
 	if(proc.exitStatus() != 0)
 		return false;
 
-	const QByteArray data = proc.collectedStdout();
-	QString str;
-	if ( !data.isEmpty() )
-		str = QString::fromLocal8Bit( data, data.size() );
-
-	d->genreList = QStringList::split( '\n', str );
+	QString str = QString::fromLocal8Bit( proc.collectedStdout() );
+    d->genreList = str.split( '\n', QString::SkipEmptyParts );
 	// Remove the numbers in front of every genre
 	for( QStringList::Iterator it = d->genreList.begin(); it != d->genreList.end(); ++it ) {
 		QString& genre = *it;
-		uint i = 0;
+		int i = 0;
 		while ( i < genre.length() && ( genre[i].isSpace() || genre[i].isDigit() ) )
 			++i;
 		genre = genre.mid( i );
 
 	}
-	//kdDebug(7117) << "Available genres:" << d->genreList << endl;
+	//kDebug(7117) << "Available genres:" << d->genreList;
 
 	return true;
 }
@@ -114,7 +125,7 @@ bool EncoderLame::init(){
 void EncoderLame::loadSettings(){
 	// Generate the command line arguments for the current settings
 	args.clear();
-
+ 
 	Settings *settings = Settings::self();
 
 	int quality = settings->quality();
@@ -122,7 +133,7 @@ void EncoderLame::loadSettings(){
 	if (quality > 9) quality = 9;
 
 	int method = settings->bitrate_constant() ? 0 : 1 ;
-
+  
 	if (method == 0) {
 		// Constant Bitrate Encoding
 		args.append("-b");
@@ -210,12 +221,12 @@ unsigned long EncoderLame::size(long time_secs) const {
 }
 
 long EncoderLame::readInit(long /*size*/){
-	// Create KProcess
-	d->currentEncodeProcess	= new KProcess(0);
-	QString prefix = locateLocal("tmp", "");
-	d->tempFile = new KTempFile(prefix, ".mp3");
-	d->tempFile->setAutoDelete(true);
-	d->lastErrorMessage = QString::null;
+	// Create K3Process
+	d->currentEncodeProcess	= new K3Process(0);
+	d->tempFile = new KTemporaryFile();
+	d->tempFile->setSuffix(".mp3");
+	d->tempFile->open();
+	d->lastErrorMessage.clear();
 	d->processHasExited = false;
 
 	// -x bitswap
@@ -224,7 +235,7 @@ long EncoderLame::readInit(long /*size*/){
 #if __BYTE_ORDER == __LITTLE_ENDIAN
 	*(d->currentEncodeProcess)	<< "lame" << "--verbose" << "-x" << "-r" << "-s" << "44.1";
 #else
-	*(d->currentEncodeProcess)      << "lame" << "--verbose" << "-r" << "-s" << "44.1";
+	*(d->currentEncodeProcess) << "lame" << "--verbose" << "-r" << "-s" << "44.1";
 #endif
 
 	*(d->currentEncodeProcess) << args;
@@ -232,43 +243,43 @@ long EncoderLame::readInit(long /*size*/){
 		*d->currentEncodeProcess << trackInfo;
 
 	// Read in stdin, output to the temp file
-	*d->currentEncodeProcess << "-" << d->tempFile->name().latin1();
+	*d->currentEncodeProcess << "-" << d->tempFile->fileName().toLatin1();
+	
+	//kDebug(7117) << d->currentEncodeProcess->args();
+	
+	
+	connect(d->currentEncodeProcess, SIGNAL(receivedStdout(K3Process *, char *, int)),
+                         this, SLOT(receivedStdout(K3Process *, char *, int)));
+	connect(d->currentEncodeProcess, SIGNAL(receivedStderr(K3Process *, char *, int)),
+                         this, SLOT(receivedStderr(K3Process *, char *, int)));
+	connect(d->currentEncodeProcess, SIGNAL(wroteStdin(K3Process *)),
+                         this, SLOT(wroteStdin(K3Process *)));
 
-	//kdDebug(7117) << d->currentEncodeProcess->args() << endl;
-
-
-	connect(d->currentEncodeProcess, SIGNAL(receivedStdout(KProcess *, char *, int)),
-	                 this, SLOT(receivedStdout(KProcess *, char *, int)));
-	connect(d->currentEncodeProcess, SIGNAL(receivedStderr(KProcess *, char *, int)),
-	                 this, SLOT(receivedStderr(KProcess *, char *, int)));
-	connect(d->currentEncodeProcess, SIGNAL(wroteStdin(KProcess *)),
-	                 this, SLOT(wroteStdin(KProcess *)));
-
-	connect(d->currentEncodeProcess, SIGNAL(processExited(KProcess *)),
-	                 this, SLOT(processExited(KProcess *)));
+	connect(d->currentEncodeProcess, SIGNAL(processExited(K3Process *)),
+                         this, SLOT(processExited(K3Process *)));
 
 	// Launch!
-	d->currentEncodeProcess->start(KProcess::NotifyOnExit, KShellProcess::All);
+	d->currentEncodeProcess->start(K3Process::NotifyOnExit, K3ShellProcess::All);
 	return 0;
 }
 
-void EncoderLame::processExited ( KProcess *process ){
-	kdDebug(7117) << "Lame Encoding process exited with: " << process->exitStatus() << endl;
+void EncoderLame::processExited ( K3Process *process ){
+	kDebug(7117) << "Lame Encoding process exited with: " << process->exitStatus();
 	d->processHasExited = true;
 }
 
-void EncoderLame::receivedStderr( KProcess * /*process*/, char *buffer, int /*buflen*/ ){
-	kdDebug(7117) << "Lame stderr: " << buffer << endl;
+void EncoderLame::receivedStderr( K3Process * /*process*/, char *buffer, int /*buflen*/ ){
+	kDebug(7117) << "Lame stderr: " << buffer;
 	if ( !d->lastErrorMessage.isEmpty() )
 		d->lastErrorMessage += '\t';
 	d->lastErrorMessage += QString::fromLocal8Bit( buffer );
 }
 
-void EncoderLame::receivedStdout( KProcess * /*process*/, char *buffer, int /*length*/ ){
-	kdDebug(7117) << "Lame stdout: " << buffer << endl;
+void EncoderLame::receivedStdout( K3Process * /*process*/, char *buffer, int /*length*/ ){
+	kDebug(7117) << "Lame stdout: " << buffer;
 }
 
-void EncoderLame::wroteStdin( KProcess * /*procces*/ ){
+void EncoderLame::wroteStdin( K3Process * /*procces*/ ){
 	d->waitingForWrite = false;
 }
 
@@ -285,12 +296,12 @@ long EncoderLame::read(int16_t *buf, int frames){
 	// We can't return until the buffer has been written
 	d->waitingForWrite = true;
 	while(d->waitingForWrite && d->currentEncodeProcess->isRunning()){
-		kapp->processEvents();
+		qApp->processEvents();
 		usleep(1);
 	}
 
 	// Determine the file size increase
-	QFileInfo file(d->tempFile->name());
+	QFileInfo file(d->tempFile->fileName());
 	uint change = file.size() - d->lastSize;
 	d->lastSize = file.size();
 	return change;
@@ -303,20 +314,18 @@ long EncoderLame::readCleanup(){
 	// Let lame tag the first frame of the mp3
 	d->currentEncodeProcess->closeStdin();
 	while( d->currentEncodeProcess->isRunning()){
-		kapp->processEvents();
+		qApp->processEvents();
 		usleep(1);
 	}
 
 	// Now copy the file out of the temp into kio
-	QFile file( d->tempFile->name() );
-	if ( file.open( IO_ReadOnly ) ) {
-		QByteArray output;
+	QFile file( d->tempFile->fileName() );
+	if ( file.open( QIODevice::ReadOnly ) ) {
 		char data[1024];
 		while ( !file.atEnd() ) {
-			uint read = file.readBlock(data, 1024);
-			output.setRawData(data, read);
+			uint read = file.read(data, 1024);
+			QByteArray output(data, read);
 			ioslave->data(output);
-			output.resetRawData(data, read);
 		}
 		file.close();
 	}
@@ -325,34 +334,34 @@ long EncoderLame::readCleanup(){
 	delete d->currentEncodeProcess;
 	delete d->tempFile;
 	d->lastSize = 0;
-
+	
 	return 0;
 }
 
 void EncoderLame::fillSongInfo( KCDDB::CDInfo info, int track, const QString &comment ){
 	trackInfo.clear();
 	trackInfo.append("--tt");
-	trackInfo.append(info.trackInfoList[track].get("title").toString());
+	trackInfo.append(info.track(track).get(Title).toString());
 
 	trackInfo.append("--ta");
-	trackInfo.append(info.get("artist").toString());
+	trackInfo.append(info.track(track).get(Artist).toString());
 
 	trackInfo.append("--tl");
-	trackInfo.append(info.get("title").toString());
+	trackInfo.append(info.get(Title).toString());
 
 	trackInfo.append("--ty");
-	trackInfo.append(QString("%1").arg(info.get("year").toString()));
+	trackInfo.append(QString("%1").arg(info.get(Year).toString()));
 
 	trackInfo.append("--tc");
 	trackInfo.append(comment);
 
 	trackInfo.append("--tn");
-	trackInfo.append(QString("%1").arg(track+1));
+	trackInfo.append(QString("%1").arg(track));
 
-	const QString genre = info.get( "genre" ).toString();
-	if ( d->genreList.find( genre ) != d->genreList.end() )
+	const QString genre = info.get(Genre).toString();
+	if ( d->genreList.indexOf( genre ) != -1 )
 	{
-		trackInfo.append("--tg");
+	trackInfo.append("--tg");
 		trackInfo.append(genre);
 	}
 }
