@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 // for operator<<()
@@ -27,55 +27,63 @@
 #include "volume.h"
 
 
-int Volume::_channelMaskEnum[10] =
+int Volume::_channelMaskEnum[8] =
     { MLEFT, MRIGHT, MCENTER,
-      MREARLEFT, MREARRIGHT, MWOOFER,
-      MLEFTREC , MRIGHTREC ,
-      MCUSTOM1, MCUSTOM2
+      MWOOFER,
+      MSURROUNDLEFT, MSURROUNDRIGHT,
+      MREARLEFT, MREARRIGHT,
     };
 
-Volume::Volume( ChannelMask chmask, long maxVolume, long minVolume, bool isCapture  )
+Volume::Volume()
 {
-  init(chmask, maxVolume, minVolume, isCapture);
+    init( Volume::MNONE, 0, 0, false, false);
+}
+
+Volume::Volume( ChannelMask chmask, long maxVolume, long minVolume, bool hasSwitch, bool isCapture  )
+{
+    init(chmask, maxVolume, minVolume, hasSwitch, isCapture );
 }
 
 
-// @ compatiblity constructor
+/* // @ compatibility constructor  @todo remove it
 Volume::Volume( int channels, long maxVolume ) {
    if (channels == 1 ) {
-       init(Volume::MLEFT, maxVolume, 0, false);
+       init(Volume::MLEFT, maxVolume, 0, false, false);
    }
    else if (channels == 2) {
-      init(ChannelMask(Volume::MLEFT|Volume::MRIGHT), maxVolume, 0, false );
+      init(ChannelMask(Volume::MLEFT|Volume::MRIGHT), maxVolume, 0, false, false );
    }
    else {
-     init(ChannelMask(Volume::MLEFT|Volume::MRIGHT), maxVolume, 0, false );
-     kdError(67100) << "Warning: Multi-channel Volume object created with old constructor - this will not work fully\n";
+     init(ChannelMask(Volume::MLEFT|Volume::MRIGHT), maxVolume, 0, false, false );
+     kError(67100) << "Warning: Multi-channel Volume object created with old constructor - this will not work fully\n";
    }
 }
+*/
 
 Volume::Volume( const Volume &v )
 {
-    _chmask     = v._chmask;
-    _maxVolume  = v._maxVolume;
-    _minVolume  = v._minVolume;
-    _muted      = v._muted;
-    _isCapture  = v._isCapture;
+    _chmask          = v._chmask;
+    _maxVolume       = v._maxVolume;
+    _minVolume       = v._minVolume;
+    _hasSwitch       = v._hasSwitch;
+    _switchActivated = v._switchActivated;
+    _isCapture       = v._isCapture;
     setVolume(v, (ChannelMask)v._chmask);
-
-    //    kdDebug(67100) << "Volume::copy-constructor initialized " << v << "\n";
+    //    kDebug(67100) << "Volume::copy-constructor initialized " << v << "\n";
 }
 
-void Volume::init( ChannelMask chmask, long maxVolume, long minVolume, bool isCapture )
+void Volume::init( ChannelMask chmask, long maxVolume, long minVolume, bool hasSwitch, bool isCapture )
 {
     for ( int i=0; i<= Volume::CHIDMAX; i++ ) {
-	_volumes[i] = 0;
+        _volumes[i] = 0;
     }
-    _chmask     = chmask;
-    _maxVolume  = maxVolume;
-    _minVolume  = minVolume;
-    _isCapture = isCapture;
-    _muted      = false;
+    _chmask          = chmask;
+    _maxVolume       = maxVolume;
+    _minVolume       = minVolume;
+    _hasSwitch       = hasSwitch;
+    _isCapture       = isCapture;
+    _muted           = false;
+    _switchActivated = false;
 }
 
 // @ compatibility
@@ -136,6 +144,25 @@ long Volume::minVolume() {
   return _minVolume;
 }
 
+int Volume::percentage(long absoluteVolume)
+{
+   int relativeVolume = 0;
+   if ( _maxVolume == 0 )
+      return 0;
+
+   if ( absoluteVolume > _maxVolume )
+      relativeVolume = 100;
+   else if ( absoluteVolume < _minVolume )
+      relativeVolume = -100;
+   else if ( absoluteVolume > 0 )
+      relativeVolume = ( 100*absoluteVolume) / _maxVolume;
+   else if ( absoluteVolume < 0 )
+      relativeVolume = ( 100*absoluteVolume) / _minVolume;
+
+   return relativeVolume;
+}
+
+
 // @ compatibility
 long Volume::operator[](int id) {
   return getVolume( (Volume::ChannelID) id );
@@ -180,16 +207,6 @@ long Volume::getAvgVolume(ChannelMask chmask) {
     return (long)sumOfActiveVolumes;
 }
 
-long Volume::getTopStereoVolume(ChannelMask chmask) {
-    long long topVolumeCount = 0;
-    for ( int i=0; i<= Volume::CHIDMAX; i++ ) {
-        if ( (_channelMaskEnum[i] & _chmask) & (int)chmask ) {
-			  if ( topVolumeCount < _volumes[i] )
-				  topVolumeCount = _volumes[i];
-        }
-    }
-    return (long)topVolumeCount;
-}
 
 int Volume::count() {
     int counter = 0;
