@@ -16,23 +16,31 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
  */
 
 #ifndef CONFIGWIDGET_H
 #define CONFIGWIDGET_H
 
-#include "configWidgetUI.h"
+#include "ui_configWidgetUI.h"
 
 class KSCD;
 
+class configWidgetUI : public QWidget, public Ui::configWidgetUI
+{
+   public:
+      explicit configWidgetUI( QWidget *parent ) : QWidget( parent ) {
+         setupUi( this );
+      }
+};
+
 class configWidget : public configWidgetUI
 {
    Q_OBJECT
 
    public:
-        configWidget(KSCD* player, QWidget* parent = 0, const char* name = 0);
+        explicit configWidget(KSCD* player, QWidget* parent = 0);
         ~configWidget();
 
    protected:
@@ -41,9 +49,6 @@ class configWidget : public configWidgetUI
    public slots:
        virtual void kcfg_DigitalPlayback_toggled(bool);
        virtual void kcfg_SelectEncoding_toggled(bool);
-       virtual void configDone();
-   private:
-       void getMediaDevices();
 };
 
 #endif // CONFIGWIDGET_H
