@@ -15,15 +15,15 @@
 
   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-  Boston, MA 02111-1307, USA.
+  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+  Boston, MA 02110-1301, USA.
 */
 
+#include "httplookup.h"
+
 #include <kio/job.h>
 #include <kdebug.h>
 
-#include "httplookup.h"
-
 namespace KCDDB
 {
   HTTPLookup::HTTPLookup()
@@ -36,7 +36,7 @@ namespace KCDDB
   {
   }
 
-    CDDB::Result
+    Result
   HTTPLookup::sendQuery()
   {
     QString cmd = QString( "cddb query %1 %2" )
@@ -48,14 +48,14 @@ namespace KCDDB
     return result;
   }
 
-    CDDB::Result
+    Result
   HTTPLookup::sendRead( const CDDBMatch & match )
   {
     category_  = match.first;
-    QString discid    = match.second;
+    discid_    = match.second;
 
     QString cmd = QString( "cddb read %1 %2" )
-        .arg( category_, discid );
+        .arg( category_, discid_ );
 
     makeURL( cmd );
     Result result = fetchURL();
@@ -80,7 +80,7 @@ namespace KCDDB
     // The whole query has to constructed each time as the
     // CDDB CGI script expects the parameters in strict order
 
-    cgiURL_.setQuery( QString::null );
+    cgiURL_.setQuery( QString::null );	//krazy:exclude=nullstrassign for old broken gcc
 
     QString hello = QString("%1 %2 %3 %4")
         .arg(user_, localHostName_, clientName(), clientVersion());
@@ -93,7 +93,7 @@ namespace KCDDB
     void
   HTTPLookup::jobFinished()
   {
-    QStringList lineList = QStringList::split( "\n", QString::fromUtf8(data_, data_.size()) );
+    QStringList lineList = QString::fromUtf8(data_, data_.size()).split( "\n", QString::SkipEmptyParts );
     QStringList::ConstIterator it = lineList.begin();
 
     switch ( state_ )
@@ -148,7 +148,7 @@ namespace KCDDB
 
               break;
           }
-          
+
         }
 
         break;
@@ -160,7 +160,9 @@ namespace KCDDB
 
           if ( info.load( QString::fromUtf8(data_,data_.size()) ) )
           {
-            info.category = category_;
+            info.set( "category", category_ );
+            info.set( "discid", discid_ );
+            info.set( "source", "freedb" );
             cdInfoList_.append( info );
           }
 
@@ -170,7 +172,7 @@ namespace KCDDB
 
         return;
 
-        break; 
+        break;
 
       default:
 
